<?php

/**
 * This file is part of the PHP Telegram Bot example-bot package.
 * https://github.com/php-telegram-bot/example-bot/
 *
 * (c) PHP Telegram Bot Team
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

/**
 * User "/echo" command
 *
 * Simply echo the input back to the user.
 */

namespace Longman\TelegramBot\Commands\UserCommands;

use Longman\TelegramBot\Commands\UserCommand;
use Longman\TelegramBot\Entities\ServerResponse;
use Longman\TelegramBot\Exception\TelegramException;

class PcInfoCommand extends UserCommand
{
    /**
     * @var string
     */
    protected $name = 'pcinfo';

    /**
     * @var string
     */
    protected $description = 'Show info about PC from IT-Inventory';

    /**
     * @var string
     */
    protected $usage = '/pcinfo <ID or name of PC>';

    /**
     * @var string
     */
    protected $version = '0.1.0';

    /**
     * Main command execution
     *
     * @return ServerResponse
     * @throws TelegramException
     */
    public function execute(): ServerResponse
    {
        global $config;

        $message = $this->getMessage();
        $from    = $message->getFrom();
        $user_id = $from->getId();
        $text    = $message->getText(true);

        if (!in_array($user_id,$config['users'])) {
            return $this->replyToChat('Sorry your userid is not yet allowed. Please report your userid "'.$user_id.'" to @leitgeg5mpl');
        }

        if ($text === '') {
            return $this->replyToChat('Command usage: ' . $this->getUsage());
        }
        else {
            $data=array();
            if (is_numeric($text)) {
                $data['id']=$text;
                $function='getElement';
            }
            else {
                $data['name']=$text;
                $function='getElementByName';
            }

            $postdata = http_build_query(
                array(
                    'params' => json_encode($data)
                )
            );

            $opts = array('http' =>
                array(
                    'method'  => 'POST',
                    'header'  => 'Content-Type: application/x-www-form-urlencoded',
                    'content' => $postdata
                )
            );

            $context  = stream_context_create($opts);

            $pcinfo_raw = file_get_contents('https://www.intranet.mfpl.ac.at/interface/typo3/itinventory/'.$function.'/?api_id=buerobauer_8ea77ec66a97011d4e9466707fbd7e38cf6c1e3b0741182f2c355b2612b0065c:me@ottohotzy.com', false, $context);
            $pcinfo=json_decode($pcinfo_raw);

            //return $this->replyToChat(var_export($pcinfo, true));

            $pcinfo=(array)$pcinfo->return_value;

            $reply=array();
            foreach ($pcinfo as $db_id => $db_val) {
                if (is_string($db_val))
                    $reply[]=$db_id.': '.$db_val;
            }

            if (empty($reply)) {
                return $this->replyToChat('Sorry bro, nothing found');
            }

            return $this->replyToChat(implode("\n",$reply));
        }

        //return $this->replyToChat($text);
    }
}
