<?php

/**
 * This file is part of the PHP Telegram Bot example-bot package.
 * https://github.com/php-telegram-bot/example-bot/
 *
 * (c) PHP Telegram Bot Team
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

/**
 * User "/echo" command
 *
 * Simply echo the input back to the user.
 */

namespace Longman\TelegramBot\Commands\UserCommands;

use Longman\TelegramBot\Commands\UserCommand;
use Longman\TelegramBot\Entities\ServerResponse;
use Longman\TelegramBot\Exception\TelegramException;

class PcnameCommand extends UserCommand
{
    /**
     * @var string
     */
    protected $name = 'pcname';

    /**
     * @var string
     */
    protected $description = 'Show a list pf PC names from GLPI';

    /**
     * @var string
     */
    protected $usage = '/pcname <part of pcname in GLPI>';

    /**
     * @var string
     */
    protected $version = '0.1.0';

    /**
     * Main command execution
     *
     * @return ServerResponse
     * @throws TelegramException
     */
    public function execute(): ServerResponse
    {
        global $config;

        $message = $this->getMessage();
        $from    = $message->getFrom();
        $user_id = $from->getId();
        $text    = $message->getText(true);

        if (!in_array($user_id,$config['users'])) {
            return $this->replyToChat('Sorry your userid is not yet allowed. Please report your userid "'.$user_id.'" to @leitgeg5mpl');
        }

        if ($text === '') {
            return $this->replyToChat('Command usage: ' . $this->getUsage());
        }
        else {
            $data=array();
            $data['pcname']=$text;

            $postdata = http_build_query(
                array(
                    'params' => json_encode($data)
                )
            );

            $opts = array('http' =>
                array(
                    'method'  => 'POST',
                    'header'  => 'Content-Type: application/x-www-form-urlencoded',
                    'content' => $postdata
                )
            );

            $context  = stream_context_create($opts);

            $pcnames_raw = file_get_contents('https://www.intranet.mfpl.ac.at/interface/typo3/itinventory/getGlpiElementsByPcname/?api_id=buerobauer_8ea77ec66a97011d4e9466707fbd7e38cf6c1e3b0741182f2c355b2612b0065c:me@ottohotzy.com', false, $context);
            $pcnames=json_decode($pcnames_raw);

            $result = false;

            //$result = $this->replyToChat(var_export($pcnames_raw, true));

            if (empty((array)$pcnames->return_value)) {
                return $this->replyToChat('Sorry bro, nothing found');
            }
            foreach ((array)$pcnames->return_value as $pcname) {
                $pcname=(array)$pcname;
                $reply=array();
                $reply[]=$pcname['Computer.name'];

                $result = $this->replyToChat(implode("\n",$reply));
            }
            return $result;
        }

        //return $this->replyToChat($text);
    }
}
