<?php

/**
 * This file is part of the PHP Telegram Bot example-bot package.
 * https://github.com/php-telegram-bot/example-bot/
 *
 * (c) PHP Telegram Bot Team
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

/**
 * User "/echo" command
 *
 * Simply echo the input back to the user.
 */

namespace Longman\TelegramBot\Commands\UserCommands;

use Longman\TelegramBot\Commands\UserCommand;
use Longman\TelegramBot\Entities\ServerResponse;
use Longman\TelegramBot\Exception\TelegramException;

class UserInfoCommand extends UserCommand
{
    /**
     * @var string
     */
    protected $name = 'userinfo';

    /**
     * @var string
     */
    protected $description = 'Show info about user';

    /**
     * @var string
     */
    protected $usage = '/userinfo <part of name, userid or e-mail>';

    /**
     * @var string
     */
    protected $version = '0.1.0';

    /**
     * Main command execution
     *
     * @return ServerResponse
     * @throws TelegramException
     */
    public function execute(): ServerResponse
    {
        global $config;

        $message = $this->getMessage();
        $from    = $message->getFrom();
        $user_id = $from->getId();
        $text    = $message->getText(true);

        if (!in_array($user_id,$config['users'])) {
            return $this->replyToChat('Sorry your userid is not yet allowed. Please report your userid "'.$user_id.'" to @leitgeg5mpl');
        }

        if ($text === '') {
            return $this->replyToChat('Command usage: ' . $this->getUsage());
        }
        else {
            $data=array();
            $data['text']=$text;

            $postdata = http_build_query(
                array(
                    'params' => json_encode($data)
                )
            );

            $opts = array('http' =>
                array(
                    'method'  => 'POST',
                    'header'  => 'Content-Type: application/x-www-form-urlencoded',
                    'content' => $postdata
                )
            );

            $context  = stream_context_create($opts);

            $userlist_raw = file_get_contents('https://www.intranet.mfpl.ac.at/interface/typo3/mfplweb/getUserInfo/?api_id=mfpl_7dc056a069f39be517bcd26fc4c26e94d841cb6b016de815dd340323cb4452dc:intranet@mfpl.ac.at', false, $context);
            $userlist=json_decode($userlist_raw);

            $result = false;

            if (empty((array)$userlist->return_value)) {
                return $this->replyToChat('Sorry bro, nothing found');
            }
            foreach ((array)$userlist->return_value as $user) {
                $user=(array)$user;
                $reply=array();
                $reply[]='UserID: '.$user['userid'];
                $reply[]='Name: '.$user['firstname'].' '.$user['lastname'];
                $reply[]='E-Mail: '.$user['email'];
                $reply[]='Tel: '.$user['telephone'];
                $reply[]='Room: '.$user['building'].'/'.$user['room'];
                if ($user['group_id']>9) $reply[]='Info: '.$user['function'].' in '.$user['group']; else $reply[]='Info: '.$user['function'];
                $reply[]=$user['imageurl_orig'];

                $result = $this->replyToChat(implode("\n",$reply));
            }
            return $result;
        }

        //return $this->replyToChat($text);
    }
}
