<?php

/**
 * This file is part of the PHP Telegram Bot example-bot package.
 * https://github.com/php-telegram-bot/example-bot/
 *
 * (c) PHP Telegram Bot Team
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

/**
 * User "/echo" command
 *
 * Simply echo the input back to the user.
 */

namespace Longman\TelegramBot\Commands\UserCommands;

use Longman\TelegramBot\Commands\UserCommand;
use Longman\TelegramBot\Entities\ServerResponse;
use Longman\TelegramBot\Exception\TelegramException;

class FirewallCommand extends UserCommand
{
    /**
     * @var string
     */
    protected $name = 'firewall';

    /**
     * @var string
     */
    protected $description = 'Show firewall rules of IP or hostname';

    /**
     * @var string
     */
    protected $usage = '/firewall <IP or hostname>';

    /**
     * @var string
     */
    protected $version = '0.1.0';

    /**
     * Main command execution
     *
     * @return ServerResponse
     * @throws TelegramException
     */
    public function execute(): ServerResponse
    {
        global $config;

        $message = $this->getMessage();
        $from    = $message->getFrom();
        $user_id = $from->getId();
        $text    = $message->getText(true);

        if (!in_array($user_id,$config['users'])) {
            return $this->replyToChat('Sorry your userid is not yet allowed. Please report your userid "'.$user_id.'" to @leitgeg5mpl');
        }

        if ($text === '') {
            return $this->replyToChat('Command usage: ' . $this->getUsage());
        }
        else {

            $opts = array('http' =>
                array(
                    'method'  => 'GET',
                    'header'  => 'PRIVATE-TOKEN: glpat-oLj-smugCJsPi3B3qNen',
                )
            );

            $context  = stream_context_create($opts);

            $rules=array();
            $l=0;

            $networks=array();
            $networks[]='firewall/vlan193.fw';
            $networks[]='firewall/vlan241.fw';
            $networks[]='firewall/vlan242.fw';
            $networks[]='firewall/vlan246.fw';
            $networks[]='firewall/vlan247.fw';
            $networks[]='firewall/vlan251.fw';
            $networks[]='firewall/vlan358.fw';
            $networks[]='firewall/vlan359.fw';

            foreach ($networks as $network) {
                $output_raw = file_get_contents('https://gitlab.mfpl.ac.at/api/v4/projects/76/repository/files/'.urlencode($network).'?ref=master', false, $context);

                $output=json_decode($output_raw);

                $content=trim(base64_decode($output->content));

                $content_array=explode("\n",$content);

                $rule_seperator=reset($content_array);
                $head_raw=explode('|',next($content_array));
                $head=array();
                foreach ($head_raw as $i=>$element) {
                    $head[$i]=trim($element);
                }

                if (next($content_array)!=$rule_seperator) {
                    $result = $this->replyToChat('Error parsing '.$network);
                }

                foreach ($content_array as $k => $line) {
                    if ($k<2) continue;
                    if (empty($line)) break;
                    if ($line==$rule_seperator) {
                        $l++;
                    }
                    else {
                        $line_arr=explode('|',$line);
                        foreach ($line_arr as $i=>$element) {
                            if ($head[$i]=='HITS') continue;
                            $element=trim($element);
                            if (!empty($element)) {
                                $rules[$l][$head[$i]][]=$element;
                            }
                            else {
                                if ($head[$i]=='DST-ZONE' && empty($rules[$l]['DST-ZONE']) && !empty($rules[$l]['NAME'])) {
                                    $rules[$l]['DST-ZONE']=$rules[$l]['NAME'];
                                }
                            }
                        }
                    }
                }
            }


            $result = false;

            foreach ($rules as $rule) {
                foreach ($rule as $i => $element) {
                    $rule[$i]=implode("\n",$rule[$i]);
                    $rule[$i]=str_replace("\n(",' (', $rule[$i]);
                }
                if (stripos($rule['SRC-NETWORK'], $text."\n")!==false || stripos($rule['SRC-NETWORK'], $text.' (')!==false || stripos($rule['DST-NETWORK'], $text."\n")!==false || stripos($rule['DST-NETWORK'], $text.' (')!==false || stripos($rule['SRC-NETWORK'], '('.$text.')')!==false || stripos($rule['DST-NETWORK'], '('.$text.')')!==false) {
                    $reply=$rule['DST-ZONE'].': '.$rule['ACTION']."\nSRC-NETWORK\n".$rule['SRC-NETWORK'];
                    if (array_key_exists('SRC-PORT',$rule)) $reply.="\nSRC-PORT\n".$rule['SRC-PORT'];
                    $reply.="\nDST-NETWORK\n".$rule['DST-NETWORK'];
                    if (array_key_exists('DST-PORT',$rule)) $reply.="\nDST-PORT\n".$rule['DST-PORT'];
                    $result = $this->replyToChat($reply);
                }
            }
            if (!$result) {
                return $this->replyToChat('Sorry bro, nothing found');
            }

            return $result;
        }

        //return $this->replyToChat($text);
    }
}
