<?php

/**
 * This file is part of the PHP Telegram Bot example-bot package.
 * https://github.com/php-telegram-bot/example-bot/
 *
 * (c) PHP Telegram Bot Team
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

/**
 * User "/echo" command
 *
 * Simply echo the input back to the user.
 */

namespace Longman\TelegramBot\Commands\UserCommands;

use Longman\TelegramBot\Commands\UserCommand;
use Longman\TelegramBot\Entities\ServerResponse;
use Longman\TelegramBot\Exception\TelegramException;

class PortCommand extends UserCommand
{
    /**
     * @var string
     */
    protected $name = 'port';

    /**
     * @var string
     */
    protected $description = 'Show info about network ports';

    /**
     * @var string
     */
    protected $usage = '/port <[part of] portname> or <Switch Switchport>';

    /**
     * @var string
     */
    protected $version = '0.1.0';

    /**
     * Main command execution
     *
     * @return ServerResponse
     * @throws TelegramException
     */
    public function execute(): ServerResponse
    {
        global $config;

        $message = $this->getMessage();
        $from    = $message->getFrom();
        $user_id = $from->getId();
        $text    = $message->getText(true);

        if (!in_array($user_id,$config['users'])) {
            return $this->replyToChat('Sorry your userid is not yet allowed. Please report your userid "'.$user_id.'" to @leitgeg5mpl');
        }

        if ($text === '') {
            return $this->replyToChat('Command usage: ' . $this->getUsage());
        }
        else {
            $text=trim($text);
            $text=str_replace('  ',' ',$text);
            $text=str_replace("\t",' ',$text);

            $opts = array('http' =>
                array(
                    'method'  => 'GET',
                    'header'  => 'Authorization: Basic '. base64_encode("it-management:WUMPxDCTEGwxeiGDKlDwlF6Yd"),
                )
            );

            $context  = stream_context_create($opts);

            $portlist_raw = file_get_contents('https://support.maxperutzlabs.ac.at/network/landosen/api.php?port='.urlencode($text), false, $context);
            $portlist=json_decode($portlist_raw);

            if (empty($portlist)) {
                return $this->replyToChat('Port not found. Maybe try parts of the portname or with/without "."');
            }

            $result = false;

            foreach ($portlist as $port) {
                $result = $this->replyToChat(implode(' ',$port));
            }
            if (!$result) {
                return $this->replyToChat('Sorry bro, nothing found');
            }
            return $result;
        }

        //return $this->replyToChat($text);
    }
}
